@@ -19,11 +19,11 @@ Dancer::Plugin::Interchange6 - Interchange6 Shop Plugin for Dancer
 
 =head1 VERSION
 
-Version 0.086
+Version 0.100
 
 =cut
 
-our $VERSION = '0.086';
+our $VERSION = '0.100';
 
 =head1 REQUIREMENTS
 
@@ -110,6 +110,10 @@ Returns L<Dancer::Plugin::Interchange6::Cart> object.
 
 Creates payment order and authorizes amount.
 
+=head2 shop_redirect
+
+Calls L<Interchange6::Schema::ResultSet::UriRedirect/redirect> with given args.
+
 =head2 shop_schema
 
 Returns L<Interchange6::Schema> object.
@@ -300,6 +304,10 @@ register shop_state => sub {
     _shop_resultset('State', @_);
 };
 
+register shop_redirect => sub {
+    return resultset('UriRedirect')->redirect($_[0]);
+};
+
 register shop_user => sub {
     _shop_resultset('User', @_);
 };
