@@ -370,6 +370,16 @@ sub _setup_routes {
             return template $tokens->{template}, $tokens;
         }
 
+        # check for uri redirect record
+        my ( $redirect, $status_code ) = shop_redirect($path);
+
+        if ($redirect) {
+            # redirect to specific URL
+            debug "UriRedirect record found redirecting uri $redirect"
+              . " to $path with status code $status_code";
+            return redirect( uri_for($redirect), $status_code );
+        }
+
         # display not_found page
         status 'not_found';
         forward 404;
